@@ -260,7 +260,7 @@ Run prancer for a list of snapshots
     if isRemote:
         from processor.helper.utils.compliance_utils import create_container_compliance, get_api_server, \
             get_collection_api, get_validate_token_api, get_company_prefix
-        from processor.helper.httpapi.http_utils import http_get_request, http_json_post_request
+        from processor.helper.httpapi.http_utils import http_get_request_useragent, http_json_post_request_useragent
         remoteValid = False
         if not args.gittoken:
             args.gittoken = os.environ['GITTOKEN'] if 'GITTOKEN' in os.environ else None
@@ -278,7 +278,8 @@ Run prancer for a list of snapshots
                     hdrs = {
                         "Content-Type": "application/json"
                     }
-                    status, data = http_json_post_request(validationUri, postdata, headers=hdrs, name='API TOKEN')
+                    status, data = http_json_post_request_useragent(validationUri, postdata, headers=hdrs,
+                                                                    useragent=True, name='API TOKEN')
                     if status and isinstance(status, int) and status == 200:
                         args.apitoken = data['data']['token']
                         collectionUri = get_collection_api(apiserver, args.container)
@@ -286,7 +287,7 @@ Run prancer for a list of snapshots
                             "Authorization": "Bearer %s" % args.apitoken,
                             "Content-Type": "application/json"
                         }
-                        status, data = http_get_request(collectionUri, headers=hdrs)
+                        status, data = http_get_request_useragent(collectionUri, headers=hdrs, useragent=True)
                         if status and isinstance(status, int) and status == 200:
                             if 'data' in data:
                                 collectionData = data['data']
